==> hs-dev-helper-0.0.1.tgz: package/fieldsJs/lib/groups/Button.js <==
const { Field, randomId } = require('../../index');
let GlobalGroup = require('../includes/GlobalGroup');

let Colors = require('../Colors');
let CssClass = require('../CssClass');

module.exports = class extends GlobalGroup {

	constructor() {
		super();
		this.name('button', 'Button')
		this.buttonTypeId = randomId()
		this._build()
		return this
	}
	
	_build() {
		return this._buildChildrenArray(() => {
			this.appendChildren(this.#standardFields());
			(this._showCta ? this.appendChildren(this.#ctaField()) : null);
			(this._showCssClass ? this.appendChildren(this.#cssClassField()) : null);
			(this._showEnable ? this.prependChildren(this.#enableField()) : null);
		})
	}

	// --- Show/Hide

	_showEnable = true
	showEnable(val = true) {
		this._showEnable = !!val
		return this._build()
	}

	_showCta = false
	showCta(val = true) {
		this._showCta = !!val
		return this._build()
	}

	_showCssClass = false
	showCssClass(val = true) {
		this._showCssClass = !!val
		return this._build()
	}

	// --- Settings
	
	_showSimpleOption = true
	showSimpleOption(val = true) {
		this._showSimpleOption = !!val
		return this._build()
	}
	
	_showOutlineOption = true
	showOutlineOption(val = true) {
		this._showOutlineOption = !!val
		return this._build()
	}
	
	_showStandardOption = true
	showStandardOption(val = true) {
		this._showStandardOption = !!val
		return this._build()
	}

	_defaultType = 'standard'
	defaultType(val) {
		this._defaultType = val.toString()
		return this._build()
	}

	_defaultText = 'Button Text'
	defaultText(val) {
		this._defaultText = val.toString()
		return this._build()
	}

	_defaultColor = 'primary'
	defaultColor(val) {
		this._defaultColor = val.toString()
		return this._build()
	}

	_defaultLink = '#'
	defaultLink(val) {
		this._defaultLink = val.toString()
		return this._build()
	}

	// --- Fields

	#standardFields() {
		(this._showStandardOption ? this.appendToOptions('standard', "Standard") : null);
		(this._showOutlineOption ? this.appendToOptions('outline', "Standard Outline") : null);
		(this._showSimpleOption ? this.appendToOptions('simple', "Simple") : null);
		(this._showCta ? this.appendToOptions('cta', "CTA") : null);
		let choices = this.getChoiceArrayFromOptions([]);

		let defaultChoiceFound = !!choices.find(c => c[0] == this._defaultType)
		let defaultChoice = defaultChoiceFound ? this._defaultType : (choices[0][0] || '')
		
		let showTypeField = !!(choices.length > 1)
		let regexOptions = `(standard|outline|simple)`

		return [
			Field
				.choice()
				.name('button_type', 'Button Type')
				.id(this.buttonTypeId)
				.locked(!showTypeField)
				.choices(choices)
				.default(defaultChoice),
			Field
				.text()
				.name('button_label','Button Label')
				.applyIf(showTypeField, f => f.visibleIf(this.buttonTypeId, regexOptions, 'MATCHES_REGEX'))
				.default(this._defaultText),
			
			// Button Style
			new Colors()
				.name('button_style', 'Button Style')
				.applyIf(showTypeField, f => f.visibleIf(this.buttonTypeId, regexOptions, 'MATCHES_REGEX'))
				.default(this._defaultColor),
	
			// Link
			Field
				.link()
				.name('button_link','Button Link')
				.applyIf(showTypeField, f => f.visibleIf(this.buttonTypeId, regexOptions, 'MATCHES_REGEX'))
				.default(this._defaultLink)
		]
	}

	#enableField() {
		return Field
			.boolean()
			.name('visible', 'Enable this Button')
			.inlineHelpText('Check to show button.')
			.set('display', 'toggle')
			.default(true)
	}

	#ctaField() {
		return Field
			.cta()
			.name('cta','CTA')
			.visibleIf(this.buttonTypeId, 'cta')
	}

	#cssClassField() {
		return new CssClass()
	}

}

==> hs-dev-helper-0.2.4.tgz: package/fieldsJs/lib/groups/Button.js <==
const { Field, randomId } = require('../../../build');
let GlobalGroup = require('../includes/GlobalGroup');

let Colors = require('../Colors');
let CssClass = require('../CssClass');

module.exports = class extends GlobalGroup {

	constructor() {
		super();
		this.name('button', 'Button')
		this.buttonTypeId = randomId()
		this._build()
		return this
	}
	
	_build() {
		return this._buildChildrenArray(() => {
			this.appendChildren(this.#standardFields());
			(this._showCta ? this.appendChildren(this.#ctaField()) : null);
			(this._showCssClass ? this.appendChildren(this.#cssClassField()) : null);
			(this._showEnable ? this.prependChildren(this.#enableField()) : null);
		})
	}

	// --- Show/Hide

	_showEnable = true
	showEnable(val = true) {
		this._showEnable = !!val
		return this._build()
	}

	_showCta = false
	showCta(val = true) {
		this._showCta = !!val
		return this._build()
	}

	_showCssClass = true
	showCssClass(val = true) {
		this._showCssClass = !!val
		return this._build()
	}

	// --- Settings
	
	_showSimpleOption = true
	showSimpleOption(val = true) {
		this._showSimpleOption = !!val
		return this._build()
	}
	
	_showOutlineOption = true
	showOutlineOption(val = true) {
		this._showOutlineOption = !!val
		return this._build()
	}
	
	_showStandardOption = true
	showStandardOption(val = true) {
		this._showStandardOption = !!val
		return this._build()
	}

	_defaultType = 'standard'
	defaultType(val) {
		this._defaultType = val.toString()
		return this._build()
	}

	_defaultText = 'Button Text'
	defaultText(val) {
		this._defaultText = val.toString()
		return this._build()
	}

	_defaultColor = 'primary'
	defaultColor(val) {
		this._defaultColor = val.toString()
		return this._build()
	}

	_defaultLink = '#'
	defaultLink(val) {
		this._defaultLink = val.toString()
		return this._build()
	}

	// --- Fields

	#standardFields() {
		(this._showStandardOption ? this.appendToOptions('standard', "Standard") : null);
		(this._showOutlineOption ? this.appendToOptions('outline', "Standard Outline") : null);
		(this._showSimpleOption ? this.appendToOptions('simple', "Simple") : null);
		(this._showCta ? this.appendToOptions('cta', "CTA") : null);
		let choices = this.getChoiceArrayFromOptions([]);

		let defaultChoiceFound = !!choices.find(c => c[0] == this._defaultType)
		let defaultChoice = defaultChoiceFound ? this._defaultType : (choices[0][0] || '')
		
		let showTypeField = !!(choices.length > 1)
		let regexOptions = `(standard|outline|simple)`

		return [
			Field
				.choice()
				.name('button_type', 'Button Type')
				.id(this.buttonTypeId)
				.locked(!showTypeField)
				.choices(choices)
				.default(defaultChoice),
			Field
				.text()
				.name('button_label','Button Label')
				.applyIf(showTypeField, f => f.visibleIf(this.buttonTypeId, regexOptions, 'MATCHES_REGEX'))
				.default(this._defaultText),
			
			// Button Style
			new Colors()
				.name('button_style', 'Button Style')
				.applyIf(showTypeField, f => f.visibleIf(this.buttonTypeId, regexOptions, 'MATCHES_REGEX'))
				.default(this._defaultColor),
	
			// Link
			Field
				.link()
				.name('button_link','Button Link')
				.applyIf(showTypeField, f => f.visibleIf(this.buttonTypeId, regexOptions, 'MATCHES_REGEX'))
				.default(this._defaultLink)
		]
	}

	#enableField() {
		return Field
			.boolean()
			.name('visible', 'Enable this Button')
			.inlineHelpText('Check to show button.')
			.set('display', 'toggle')
			.default(true)
	}

	#ctaField() {
		return Field
			.cta()
			.name('cta','CTA')
			.visibleIf(this.buttonTypeId, 'cta')
	}

	#cssClassField() {
		return new CssClass()
	}

}
